@@ -1,10 +1,7 @@
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
 
-from abc import ABCMeta
+from abc import ABCMeta, abstractmethod
 from collections.abc import Callable
 from functools import wraps
 from hashlib import sha256
@@ -53,9 +50,11 @@ class Lazy(metaclass=ABCMeta):
             if temp.exists():
                 temp.unlink()
 
+    @abstractmethod
     def _create(self, path: Path) -> None:
         raise NotImplementedError()
 
+    @abstractmethod
     def hash(self) -> str:
         raise NotImplementedError()
 
