@@ -1,8 +1,5 @@
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
 
 import datetime
 import sys
@@ -46,7 +43,7 @@ class EC2_EBS(Target):
     public = False
 
     def create(self, image: Raw) -> None:
-        vmdk = Vmdk(image)
+        vmdk = Vmdk(image, subformat="streamOptimized")
 
         s3 = boto3.client("s3", region_name=self.options.region)
         vmdk_get = self.upload_file(s3, vmdk, self.options.bucket)
